@@ -142,6 +142,14 @@ class DyGraph:
     def get_nodes_states(self):
         return self._nodes_states
 
+    def avg_degree(self):
+        import numpy as np
+        average_dygraph_degree = []
+        for (slice_id, s) in self._slices.iteritems():
+            G = s['graph']
+            average_dygraph_degree.append(np.mean(G.degree().values()))
+        return np.mean(average_dygraph_degree)
+
     def generate_mobility_levy_walk(
         self,
         alpha,
