@@ -203,6 +203,10 @@ class PGG_diffusion:
         self._G.node[node_id]['strategy'] = 'C'
         self._G.node[node_id]['time_stamp'] = time_stamp
 
+    def set_sent_update(self, sent_update):
+       for (key, val) in sent_update.iteritems():
+            self._G.node[key]['sent_update'] = val
+
     #
     # Get
     #
@@ -231,6 +235,12 @@ class PGG_diffusion:
             states[node] = self._G.node[node]['state']
         return states
 
+    def get_sent_update(self):
+        sent_update = {}
+        for node in self._G.nodes():
+            sent_update[node] = self._G.node[node]['sent_update']
+        return sent_update
+
     #
     # Reset
     #
